@@ -4,7 +4,11 @@
  *
  * @author Carla Schroder <carla@owncloud.com>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Sujith H <sharidasan@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
  * @license AGPL-3.0
  *
@@ -28,6 +32,7 @@ use OC\Files\Filesystem;
 use OC\Files\View;
 use OCP\Files\FileInfo;
 use OCP\Files\IHomeStorage;
+use OCP\Files\IRootFolder;
 use OCP\Files\Mount\IMountManager;
 use OCP\IUser;
 use OCP\IUserManager;
@@ -72,7 +77,10 @@ class TransferOwnership extends Command {
 	/** @var string */
 	private $finalTarget;
 
-	public function __construct(IUserManager $userManager, IManager $shareManager, IMountManager $mountManager) {
+	public function __construct(IUserManager $userManager,
+								IManager $shareManager,
+								IMountManager $mountManager,
+								IRootFolder $rootFolder) {
 		$this->userManager = $userManager;
 		$this->shareManager = $shareManager;
 		$this->mountManager = $mountManager;
@@ -170,6 +178,15 @@ class TransferOwnership extends Command {
 	 */
 	protected function analyse(OutputInterface $output) {
 		$view = new View();
+
+		$output->writeln('Validating quota');
+		$size = $view->getFileInfo($this->sourcePath, false)->getSize(false);
+		$freeSpace = $view->free_space($this->destinationUser . '/files/');
+		if ($size > $freeSpace) {
+			$output->writeln('<error>Target user does not have enough free space available</error>');
+			throw new \Exception('Execution terminated');
+		}
+
 		$output->writeln("Analysing files of $this->sourceUser ...");
 		$progress = new ProgressBar($output);
 		$progress->start();
@@ -203,7 +220,6 @@ class TransferOwnership extends Command {
 			}
 			throw new \Exception('Execution terminated.');
 		}
-
 	}
 
 	/**
@@ -213,7 +229,7 @@ class TransferOwnership extends Command {
 		$output->writeln("Collecting all share information for files and folder of $this->sourceUser ...");
 
 		$progress = new ProgressBar($output, count($this->shares));
-		foreach([\OCP\Share::SHARE_TYPE_GROUP, \OCP\Share::SHARE_TYPE_USER, \OCP\Share::SHARE_TYPE_LINK, \OCP\Share::SHARE_TYPE_REMOTE] as $shareType) {
+		foreach([\OCP\Share::SHARE_TYPE_GROUP, \OCP\Share::SHARE_TYPE_USER, \OCP\Share::SHARE_TYPE_LINK, \OCP\Share::SHARE_TYPE_REMOTE, \OCP\Share::SHARE_TYPE_ROOM] as $shareType) {
 		$offset = 0;
 			while (true) {
 				$sharePage = $this->shareManager->getSharesBy($this->sourceUser, $shareType, null, true, 50, $offset);
