@@ -37,6 +37,7 @@
 namespace OCA\User_LDAP;
 
 use OC\ServerNotAvailableException;
+use OCP\ILogger;
 
 /**
  * magic properties (incomplete)
@@ -49,7 +50,6 @@ use OC\ServerNotAvailableException;
  * @property string ldapUserDisplayName2
  * @property string ldapUserAvatarRule
  * @property boolean turnOnPasswordChange
- * @property boolean hasPagedResultSupport
  * @property string[] ldapBaseUsers
  * @property int|null ldapPagingSize holds an integer
  * @property bool|mixed|void ldapGroupMemberAssocAttr
@@ -60,13 +60,17 @@ use OC\ServerNotAvailableException;
  * @property string ldapQuotaAttribute
  * @property string ldapQuotaDefault
  * @property string ldapEmailAttribute
+ * @property string ldapExtStorageHomeAttribute
+ * @property string homeFolderNamingRule
+ * @property bool|string ldapNestedGroups
+ * @property string[] ldapBaseGroups
+ * @property string ldapGroupFilter
  */
 class Connection extends LDAPUtility {
 	private $ldapConnectionRes = null;
 	private $configPrefix;
 	private $configID;
 	private $configured = false;
-	private $hasPagedResultSupport = true;
 	//whether connection should be kept on __destruct
 	private $dontDestruct = false;
 
@@ -111,16 +115,13 @@ class Connection extends LDAPUtility {
 		$helper = new Helper(\OC::$server->getConfig());
 		$this->doNotValidate = !in_array($this->configPrefix,
 			$helper->getServerConfigurationPrefixes());
-		$this->hasPagedResultSupport =
-			intval($this->configuration->ldapPagingSize) !== 0
-			|| $this->ldap->hasPagedResultSupport();
 	}
 
 	public function __destruct() {
 		if(!$this->dontDestruct && $this->ldap->isResource($this->ldapConnectionRes)) {
 			@$this->ldap->unbind($this->ldapConnectionRes);
+			$this->bindResult = [];
 		}
-		$this->bindResult = [];
 	}
 
 	/**
@@ -145,10 +146,6 @@ class Connection extends LDAPUtility {
 			$this->readConfiguration();
 		}
 
-		if($name === 'hasPagedResultSupport') {
-			return $this->hasPagedResultSupport;
-		}
-
 		return $this->configuration->$name;
 	}
 
@@ -208,7 +205,7 @@ class Connection extends LDAPUtility {
 			$this->establishConnection();
 		}
 		if(is_null($this->ldapConnectionRes)) {
-			\OCP\Util::writeLog('user_ldap', 'No LDAP Connection to server ' . $this->configuration->ldapHost, \OCP\Util::ERROR);
+			\OCP\Util::writeLog('user_ldap', 'No LDAP Connection to server ' . $this->configuration->ldapHost, ILogger::ERROR);
 			throw new ServerNotAvailableException('Connection to LDAP server could not be established');
 		}
 		return $this->ldapConnectionRes;
@@ -382,13 +379,13 @@ class Connection extends LDAPUtility {
 					\OCP\Util::writeLog('user_ldap',
 										'Illegal value for the '.
 										$effectiveSetting.', '.'reset to '.
-										'autodetect.', \OCP\Util::INFO);
+										'autodetect.', ILogger::INFO);
 				}
 
 			}
 		}
 
-		$backupPort = intval($this->configuration->ldapBackupPort);
+		$backupPort = (int)$this->configuration->ldapBackupPort;
 		if ($backupPort <= 0) {
 			$this->configuration->backupPort = $this->configuration->ldapPort;
 		}
@@ -406,10 +403,11 @@ class Connection extends LDAPUtility {
 		if((stripos($this->configuration->ldapHost, 'ldaps://') === 0)
 			&& $this->configuration->ldapTLS) {
 			$this->configuration->ldapTLS = false;
-			\OCP\Util::writeLog('user_ldap',
-								'LDAPS (already using secure connection) and '.
-								'TLS do not work together. Switched off TLS.',
-								\OCP\Util::INFO);
+			\OCP\Util::writeLog(
+				'user_ldap',
+				'LDAPS (already using secure connection) and TLS do not work together. Switched off TLS.',
+				ILogger::INFO
+			);
 		}
 	}
 
@@ -419,7 +417,7 @@ class Connection extends LDAPUtility {
 	private function doCriticalValidation() {
 		$configurationOK = true;
 		$errorStr = 'Configuration Error (prefix '.
-					strval($this->configPrefix).'): ';
+			(string)$this->configPrefix .'): ';
 
 		//options that shall not be empty
 		$options = array('ldapHost', 'ldapPort', 'ldapUserDisplayName',
@@ -448,9 +446,11 @@ class Connection extends LDAPUtility {
 						break;
 				}
 				$configurationOK = false;
-				\OCP\Util::writeLog('user_ldap',
-									$errorStr.'No '.$subj.' given!',
-									\OCP\Util::WARN);
+				\OCP\Util::writeLog(
+					'user_ldap',
+					$errorStr.'No '.$subj.' given!',
+					ILogger::WARN
+				);
 			}
 		}
 
@@ -461,11 +461,11 @@ class Connection extends LDAPUtility {
 			($agent === ''  && $pwd !== '')
 			|| ($agent !== '' && $pwd === '')
 		) {
-			\OCP\Util::writeLog('user_ldap',
-								$errorStr.'either no password is given for the '.
-								'user agent or a password is given, but not an '.
-								'LDAP agent.',
-				\OCP\Util::WARN);
+			\OCP\Util::writeLog(
+				'user_ldap',
+				$errorStr.'either no password is given for the user ' .
+					'agent or a password is given, but not an LDAP agent.',
+				ILogger::WARN);
 			$configurationOK = false;
 		}
 
@@ -474,18 +474,21 @@ class Connection extends LDAPUtility {
 		$baseGroups = $this->configuration->ldapBaseGroups;
 
 		if(empty($base) && empty($baseUsers) && empty($baseGroups)) {
-			\OCP\Util::writeLog('user_ldap',
-								$errorStr.'Not a single Base DN given.',
-								\OCP\Util::WARN);
+			\OCP\Util::writeLog(
+				'user_ldap',
+				$errorStr.'Not a single Base DN given.',
+				ILogger::WARN
+			);
 			$configurationOK = false;
 		}
 
 		if(mb_strpos($this->configuration->ldapLoginFilter, '%uid', 0, 'UTF-8')
 		   === false) {
-			\OCP\Util::writeLog('user_ldap',
-								$errorStr.'login filter does not contain %uid '.
-								'place holder.',
-								\OCP\Util::WARN);
+			\OCP\Util::writeLog(
+				'user_ldap',
+				$errorStr.'login filter does not contain %uid place holder.',
+				ILogger::WARN
+			);
 			$configurationOK = false;
 		}
 
@@ -529,18 +532,21 @@ class Connection extends LDAPUtility {
 			return false;
 		}
 		if(!$this->ignoreValidation && !$this->configured) {
-			\OCP\Util::writeLog('user_ldap',
-								'Configuration is invalid, cannot connect',
-								\OCP\Util::WARN);
+			\OCP\Util::writeLog(
+				'user_ldap',
+				'Configuration is invalid, cannot connect',
+				ILogger::WARN
+			);
 			return false;
 		}
 		if(!$this->ldapConnectionRes) {
 			if(!$this->ldap->areLDAPFunctionsAvailable()) {
 				$phpLDAPinstalled = false;
-				\OCP\Util::writeLog('user_ldap',
-									'function ldap_connect is not available. Make '.
-									'sure that the PHP ldap module is installed.',
-									\OCP\Util::ERROR);
+				\OCP\Util::writeLog(
+					'user_ldap',
+					'function ldap_connect is not available. Make sure that the PHP ldap module is installed.',
+					ILogger::ERROR
+				);
 
 				return false;
 			}
@@ -548,11 +554,13 @@ class Connection extends LDAPUtility {
 				if(putenv('LDAPTLS_REQCERT=never')) {
 					\OCP\Util::writeLog('user_ldap',
 						'Turned off SSL certificate validation successfully.',
-						\OCP\Util::DEBUG);
+						ILogger::DEBUG);
 				} else {
-					\OCP\Util::writeLog('user_ldap',
-										'Could not turn off SSL certificate validation.',
-										\OCP\Util::WARN);
+					\OCP\Util::writeLog(
+						'user_ldap',
+						'Could not turn off SSL certificate validation.',
+						ILogger::WARN
+					);
 				}
 			}
 
@@ -663,10 +671,11 @@ class Connection extends LDAPUtility {
 
 			\OCP\Util::writeLog('user_ldap',
 				'Bind failed: ' . $errno . ': ' . $this->ldap->error($cr),
-				\OCP\Util::WARN);
+				ILogger::WARN);
 
 			// Set to failure mode, if LDAP error code is not LDAP_SUCCESS or LDAP_INVALID_CREDENTIALS
-			if($errno !== 0x00 && $errno !== 0x31) {
+			// or (needed for Apple Open Directory:) LDAP_INSUFFICIENT_ACCESS
+			if($errno !== 0 && $errno !== 49 && $errno !== 50) {
 				$this->ldapConnectionRes = null;
 			}
 
