@@ -7,7 +7,7 @@ OC.L10N.register(
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом.",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ово се обично може средити давањем права писања веб серверу за директоријум са подешавањима. Погледајте %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, ако пре желите да задржите config.php да је само за читање, поставите опцију \"config_is_read_only\" на true у њему самом. Погледајте %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%$1s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Фајлови апликације „%1$s“ нису правилно замењени. Проверите да ли је верзија компатибилна са сервером.",
     "Sample configuration detected" : "Откривен је пример подешавања",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је прекопиран пример подешавања. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
     "%1$s and %2$s" : "%1$s и %2$s",
@@ -24,12 +24,26 @@ OC.L10N.register(
     "Following databases are supported: %s" : "Подржане су следеће базе података: %s",
     "The command line tool %s could not be found" : "Алатку командне линије „%s“ није могуће пронаћи",
     "The library %s is not available." : "Библиотека „%s“ није доступна.",
-    "Library %s with a version higher than %s is required - available version %s." : "Потребна је библиотека „%s“ верзије веће од %s - доступна верзија је %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "Потребна је библиотека „%s“ верзије ниже од %s - доступна верзија је %s.",
+    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије веће од %2$s - доступна верзија је %3$s.",
+    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потребна је библиотека „%1$s“ верзије ниже од %2$s - доступна верзија је %3$s.",
     "Following platforms are supported: %s" : "Подржане су следеће платформе: %s",
     "Server version %s or higher is required." : "Потребна је верзија сервера %s или виша.",
     "Server version %s or lower is required." : "Потребна је верзија сервера %s или нижа.",
+    "Logged in user must be an admin or sub admin" : "Пријављени корисник мора бити администратор или подадминистратор",
     "Logged in user must be an admin" : "Пријављени корисник мора бити администратор",
+    "Wiping of device %s has started" : "Започето брисање уређаја %s",
+    "Wiping of device »%s« has started" : "Удаљено брисање уређаја „%s“ је почело",
+    "»%s« started remote wipe" : "„%s“ је започео удаљено брисање",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Уређај или апликација „%s“ је започео процес удаљеног брисања. Добићете још један и-мејл када се процес заврши.",
+    "Wiping of device %s has finished" : "Брисање уређаја %s завршено",
+    "Wiping of device »%s« has finished" : "Брисање уређаја „%s“ завршено",
+    "»%s« finished remote wipe" : "„%s“ је завршио удаљено брисање",
+    "Device or application »%s« has finished the remote wipe process." : "Уређај или апликација „%s“ је завршио процес удаљеног брисања.",
+    "Remote wipe started" : "Започето удаљено брисање",
+    "A remote wipe was started on device %s" : "Започето удаљено брисање на уређају %s",
+    "Remote wipe finished" : "Удаљено брисање завршено",
+    "The remote wipe on %s has finished" : "Удаљено брисање на уређају %s завршено",
+    "Authentication" : "Провера идентитета",
     "Unknown filetype" : "Непознат тип фајла",
     "Invalid image" : "Неисправна слика",
     "Avatar image is not square" : "Слика аватара није квадратна",
@@ -68,10 +82,6 @@ OC.L10N.register(
     "Log out" : "Одјава",
     "Users" : "Корисници",
     "Unknown user" : "Непознат корисник",
-    "Create" : "Направи",
-    "Change" : "Измени",
-    "Delete" : "Обриши",
-    "Share" : "Подели",
     "Overview" : "Преглед",
     "Basic settings" : "Основне поставке",
     "Sharing" : "Дељење",
@@ -80,10 +90,6 @@ OC.L10N.register(
     "Additional settings" : "Додатне поставке",
     "Personal info" : "Лични подаци",
     "Mobile & desktop" : "Мобилни и десктоп",
-    "Unlimited" : "Неограничено",
-    "Verifying" : "Проверавам",
-    "Verifying …" : "Проверавам ...",
-    "Verify" : "Провери",
     "%s enter the database username and name." : "%s унеси корисничко име базе података и име.",
     "%s enter the database username." : "%s унеси корисничко име базе података.",
     "%s enter the database name." : "%s унеси име базе података.",
@@ -100,45 +106,23 @@ OC.L10N.register(
     "Set an admin password." : "Поставите лозинку за администратора.",
     "Can't create or write into the data directory %s" : "Не могу креирати или уписивати у директоријум података %s",
     "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Дељење %s није успело зато што позадина не дозвољава дељење од типа %i",
-    "Sharing %s failed, because the file does not exist" : "Дељење %s није успело зато што фајл не постоји",
-    "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
-    "Sharing %s failed, because you can not share with yourself" : "Дељење %s није успело зато што не можете да делите са самим собом",
-    "Sharing %s failed, because the user %s does not exist" : "Дељење %s није успело зато што не постоји корисник %s",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Дељење %s није успело зато што корисник %s није члан ниједне групе чији је %s члан",
-    "Sharing %s failed, because this item is already shared with %s" : "Дељење %s није успело зато што се ова ставка већ дели са %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
-    "Sharing %s failed, because the group %s does not exist" : "Дељење %s није успело зато што не постоји група %s",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Дељење %s није успело зато што %s није члан групе %s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Морате да обезбедите лозинку за креирање јавне везе, дозвољене су само заштићене везе",
-    "Sharing %s failed, because sharing with links is not allowed" : "Дељење %s није успело зато што дељење са везама није дозвољено",
-    "Not allowed to create a federated share with the same user" : "Није дозвољено да направите здружено дељење са истим корисником",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Дељење %s није успело, није могуће пронаћи %s, можда сервер тренутно није доступан.",
-    "Share type %s is not valid for %s" : "Тип фајла за дељење %s није исправан за %s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Не могу поставити датум трајања. Дељења не могу истицати касније од %s пошто су активирана",
-    "Cannot set expiration date. Expiration date is in the past" : "Не могу поставити датум трајања. Датум трајања употребе је у прошлости",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
     "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
     "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
-    "Sharing failed, because the user %s is the original sharer" : "Дељење није успело, зато што је корисник %s већ оригинални делилац",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Дељење %s није успело зато што дозволе превазилазе дозволе гарантоване за %s",
-    "Sharing %s failed, because resharing is not allowed" : "Дељење %s није успело зато што даље дељење није дозвољено",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Дељење %s није успело зато што позадина дељења за %s није могла да нађе извор",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Дељење %s није успело зато што фајл није нађен у кешу фајлова",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио \"%2$s\" са Вама и жели да дода:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио \"%2$s\" са Вама и жели да дода",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s је поделио „%2$s“ са Вама и жели да дода:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s је поделио „%2$s“ са Вама и жели да дода",
     "»%s« added a note to a file shared with you" : "\"%s\" је додао белешку на фајл који дели са Вама",
     "Open »%s«" : "Отвори „%s“",
     "%1$s via %2$s" : "%1$s преко %2$s",
+    "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
     "Can’t increase permissions of %s" : "Не могу да повећам дозволе за %s",
     "Files can’t be shared with delete permissions" : "Фајлови не могу бити дељени са дозволама за брисање",
     "Files can’t be shared with create permissions" : "Фајлови не могу бити дељени са дозволама за креирање",
     "Expiration date is in the past" : "Датум истека је у прошлости",
     "Can’t set expiration date more than %s days in the future" : "Не могу да поставим датум истека више од %s дана у будућност",
-    "%s shared »%s« with you" : "%s подели „%s“ са вама",
-    "%s shared »%s« with you." : "%s поделио „%s“ са Вама.",
+    "%1$s shared »%2$s« with you" : "%1$s је поделио „%2$s“ са Вама",
+    "%1$s shared »%2$s« with you." : "%1$s је поделио „%2$s“ са Вама.",
     "Click the button below to open it." : "Кликните дугме испод да га отворите.",
-    "%s via %s" : "%s путем %s",
     "The requested share does not exist anymore" : "Захтевано дељење више не постоји",
     "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
     "Sunday" : "Недеља",
@@ -190,12 +174,13 @@ OC.L10N.register(
     "A valid username must be provided" : "Морате унети исправно корисничко име",
     "Username contains whitespace at the beginning or at the end" : "Корисничко име садржи белине на почетку или на крају",
     "Username must not consist of dots only" : "Корисничко име не могу бити само тачке",
+    "Username is invalid because files already exist for this user" : "Корисничко име није исправно пошто већ постоје фајлови за овог корисника",
     "A valid password must be provided" : "Морате унети исправну лозинку",
     "The username is already being used" : "Корисничко име се већ користи",
     "Could not create user" : "Не могу да направим корисника",
     "User disabled" : "Корисник онемогућен",
     "Login canceled by app" : "Пријава отказана од стране апликације",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Апликација „%s“ не може бити инсталирана јер следеће зависности нису испуњене: %s",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликација „%1$s“ не може бити инсталирана јер следеће зависности нису испуњене: %2$s",
     "a safe home for all your data" : "сигурно место за све Ваше податке",
     "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
     "Can't read file" : "Не могу да читам фајл",
@@ -234,7 +219,7 @@ OC.L10N.register(
     "Action \"%s\" not supported or implemented." : "Радња \"%s\" није подржана или имплементирана.",
     "Authentication failed, wrong token or provider ID given" : "Неуспела провера идентитета, добијен погрешан токен или ID провајдера",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Недостају параметри да би се довршио захтев. Недостајући параметри: \"%s\"",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "Идентификацију \"%s\" већ користи провајдер здруживања \"%s\"",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Идентификацију \"%1$s\" већ користи провајдер здруживања \"%2$s\"",
     "Cloud Federation Provider with ID: \"%s\" does not exist." : "Провајдер клауд здруживања са ID-ом \"%s\" не постоји",
     "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“.",
     "Storage unauthorized. %s" : "Складиште није овлашћено. %s",
@@ -242,24 +227,34 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка приликом повезивања на складиште. %s",
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
     "Storage connection timeout. %s" : "Прекорачено време за повезивање на складиште. %s",
-    "Personal" : "Лично",
-    "Admin" : "Администратор",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "Шифровање",
-    "Tips & tricks" : "Савети и трикови",
-    "DB Error: \"%s\"" : "Грешка базе података: \"%s\"",
-    "Offending command was: \"%s\"" : "Неисправна команда је: „%s“",
-    "Offending command was: \"%s\", name: %s, password: %s" : "Неисправна команда је: „%s“, назив: %s, лозинка: %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Постављање дозвола за %s није успело зато што дозволе превазилазе дозволе гарантоване за %s",
-    "Setting permissions for %s failed, because the item was not found" : "Постављање дозвола за %s није успело зато што ставка није пронађена",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Не могу обрисати датум трајања. Дељења су у обавези да имају ограничен датум трајања.",
-    "Cannot increase permissions of %s" : "Не могу да повећам привилегије за %s",
-    "Files can't be shared with delete permissions" : "Фајлови не могу бити дељени са привилегијама за брисање",
-    "Files can't be shared with create permissions" : "Фајлови не могу бити дељени са привилегијама за прављење",
-    "Cannot set expiration date more than %s days in the future" : "Датум истека не може да се постави више од %s дана у будућност",
-    "No app name specified" : "Није наведен назив апликације",
-    "App '%s' could not be installed!" : "Апликација '%s' не може да се инсталира!",
-    "Sync clients" : "Клијенти у синхронизацији"
+    "Create" : "Направи",
+    "Change" : "Измени",
+    "Delete" : "Обриши",
+    "Share" : "Подели",
+    "Unlimited" : "Неограничено",
+    "Verifying" : "Проверавам",
+    "Verifying …" : "Проверавам ...",
+    "Verify" : "Провери",
+    "Sharing %s failed, because the backend does not allow shares from type %i" : "Дељење %s није успело зато што позадина не дозвољава дељење од типа %i",
+    "Sharing %s failed, because the file does not exist" : "Дељење %s није успело зато што фајл не постоји",
+    "Sharing %s failed, because you can not share with yourself" : "Дељење %s није успело зато што не можете да делите са самим собом",
+    "Sharing %1$s failed, because the user %2$s does not exist" : "Дељење %1$s није успело зато што не постоји корисник %2$s",
+    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Дељење %1$s није успело зато што корисник %2$s није члан ниједне групе чији је %3$s члан",
+    "Sharing %1$s failed, because this item is already shared with %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са %2$s",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Дељење %1$s није успело зато што се ова ставка већ дели са корисником %2$s",
+    "Sharing %1$s failed, because the group %2$s does not exist" : "Дељење %1$s није успело зато што не постоји група %2$s",
+    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Дељење %1$s није успело зато што %2$s није члан групе %3$s",
+    "You need to provide a password to create a public link, only protected links are allowed" : "Морате да обезбедите лозинку за креирање јавне везе, дозвољене су само заштићене везе",
+    "Sharing %s failed, because sharing with links is not allowed" : "Дељење %s није успело зато што дељење са везама није дозвољено",
+    "Not allowed to create a federated share with the same user" : "Није дозвољено да направите здружено дељење са истим корисником",
+    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Дељење %1$s није успело, није могуће пронаћи %2$s, можда сервер тренутно није доступан.",
+    "Share type %1$s is not valid for %2$s" : "Тип фајла за дељење %1$s није исправан за %2$s",
+    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Не могу поставити датум трајања. Дељења не могу истицати касније од %s пошто су активирана",
+    "Cannot set expiration date. Expiration date is in the past" : "Не могу поставити датум трајања. Датум трајања употребе је у прошлости",
+    "Sharing failed, because the user %s is the original sharer" : "Дељење није успело, зато што је корисник %s већ оригинални делилац",
+    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Дељење %1$s није успело зато што дозволе превазилазе дозволе гарантоване за %2$s",
+    "Sharing %s failed, because resharing is not allowed" : "Дељење %s није успело зато што даље дељење није дозвољено",
+    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Дељење %1$s није успело зато што позадина дељења за %2$s није могла да нађе извор",
+    "Sharing %s failed, because the file could not be found in the file cache" : "Дељење %s није успело зато што фајл није нађен у кешу фајлова"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
