@@ -26,9 +26,9 @@
 namespace OC\Files\ObjectStore;
 
 use Icewind\Streams\CallbackWrapper;
+use Icewind\Streams\CountWrapper;
 use Icewind\Streams\IteratorDirectory;
 use OC\Files\Cache\CacheEntry;
-use OC\Files\Stream\CountReadStream;
 use OCP\Files\NotFoundException;
 use OCP\Files\ObjectStore\IObjectStore;
 
@@ -161,7 +161,9 @@ class ObjectStoreStorage extends \OC\Files\Storage\Common {
 			return false;
 		}
 
-		$this->rmObjects($path);
+		if (!$this->rmObjects($path)) {
+			return false;
+		}
 
 		$this->getCache()->remove($path);
 
@@ -172,11 +174,17 @@ class ObjectStoreStorage extends \OC\Files\Storage\Common {
 		$children = $this->getCache()->getFolderContents($path);
 		foreach ($children as $child) {
 			if ($child['mimetype'] === 'httpd/unix-directory') {
-				$this->rmObjects($child['path']);
+				if (!$this->rmObjects($child['path'])) {
+					return false;
+				}
 			} else {
-				$this->unlink($child['path']);
+				if(!$this->unlink($child['path'])) {
+					return false;
+				}
 			}
 		}
+
+		return true;
 	}
 
 	public function unlink($path) {
@@ -443,7 +451,7 @@ class ObjectStoreStorage extends \OC\Files\Storage\Common {
 		try {
 			//upload to object storage
 			if ($size === null) {
-				$countStream = CountReadStream::wrap($stream, function ($writtenSize) use ($fileId, &$size) {
+				$countStream = CountWrapper::wrap($stream, function ($writtenSize) use ($fileId, &$size) {
 					$this->getCache()->update($fileId, [
 						'size' => $writtenSize
 					]);
