@@ -7,16 +7,19 @@
  * @author Clark Tomlinson <fallen013@gmail.com>
  * @author Hendrik Leppelsack <hendrik@leppelsack.de>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author John Molakvoæ (skjnldsv) <skjnldsv@protonmail.com>
+ * @author Julius Haertl <jus@bitgrid.net>
+ * @author Julius Härtl <jus@bitgrid.net>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Nils <git@to.nilsschnabel.de>
  * @author Remco Brenninkmeijer <requist1@starmail.nl>
  * @author Robin Appelman <robin@icewind.nl>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
  * @author Roeland Jago Douma <roeland@famdouma.nl>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
  * @license AGPL-3.0
  *
@@ -39,6 +42,7 @@ use OC\Template\JSCombiner;
 use OC\Template\JSConfigHelper;
 use OC\Template\SCSSCacher;
 use OCP\Defaults;
+use OC\AppFramework\Http\Request;
 
 class TemplateLayout extends \OC_Template {
 
@@ -58,9 +62,12 @@ class TemplateLayout extends \OC_Template {
 		// yes - should be injected ....
 		$this->config = \OC::$server->getConfig();
 
+		if(\OCP\Util::isIE()) {
+			\OC_Util::addStyle('ie');
+		}
 
 		// Decide which page we show
-		if($renderAs == 'user') {
+		if($renderAs === 'user') {
 			parent::__construct( 'core', 'layout.user' );
 			if(in_array(\OC_App::getCurrentApp(), ['settings','admin', 'help']) !== false) {
 				$this->assign('bodyid', 'body-settings');
@@ -68,18 +75,12 @@ class TemplateLayout extends \OC_Template {
 				$this->assign('bodyid', 'body-user');
 			}
 
-			// Code integrity notification
-			$integrityChecker = \OC::$server->getIntegrityCodeChecker();
-			if(\OC_User::isAdminUser(\OC_User::getUser()) && $integrityChecker->isCodeCheckEnforced() && !$integrityChecker->hasPassedCheck()) {
-				\OCP\Util::addScript('core', 'integritycheck-failed-notification');
-			}
-
 			// Add navigation entry
 			$this->assign( 'application', '');
 			$this->assign( 'appid', $appId );
-			$navigation = \OC_App::getNavigation();
+			$navigation = \OC::$server->getNavigationManager()->getAll();
 			$this->assign( 'navigation', $navigation);
-			$settingsNavigation = \OC_App::getSettingsNavigation();
+			$settingsNavigation = \OC::$server->getNavigationManager()->getAll('settings');
 			$this->assign( 'settingsnavigation', $settingsNavigation);
 			foreach($navigation as $entry) {
 				if ($entry['active']) {
@@ -87,7 +88,7 @@ class TemplateLayout extends \OC_Template {
 					break;
 				}
 			}
-			
+
 			foreach($settingsNavigation as $entry) {
 				if ($entry['active']) {
 					$this->assign( 'application', $entry['name'] );
@@ -114,18 +115,35 @@ class TemplateLayout extends \OC_Template {
 				$this->assign('themingInvertMenu', false);
 			}
 
-		} else if ($renderAs == 'error') {
+		} else if ($renderAs === 'error') {
 			parent::__construct('core', 'layout.guest', '', false);
 			$this->assign('bodyid', 'body-login');
-		} else if ($renderAs == 'guest') {
+			$this->assign('user_displayname', '');
+			$this->assign('user_uid', '');
+		} else if ($renderAs === 'guest') {
 			parent::__construct('core', 'layout.guest');
+			\OC_Util::addStyle('guest');
 			$this->assign('bodyid', 'body-login');
+
+			$userDisplayName = \OC_User::getDisplayName();
+			$this->assign('user_displayname', $userDisplayName);
+			$this->assign('user_uid', \OC_User::getUser());
+		} else if ($renderAs === 'public') {
+			parent::__construct('core', 'layout.public');
+			$this->assign( 'appid', $appId );
+			$this->assign('bodyid', 'body-public');
+			$this->assign('showSimpleSignUpLink', $this->config->getSystemValue('simpleSignUpLink.shown', true) !== false);
 		} else {
 			parent::__construct('core', 'layout.base');
 
 		}
-		// Send the language to our layouts
-		$this->assign('language', \OC::$server->getL10NFactory()->findLanguage());
+		// Send the language and the locale to our layouts
+		$lang = \OC::$server->getL10NFactory()->findLanguage();
+		$locale = \OC::$server->getL10NFactory()->findLocale($lang);
+
+		$lang = str_replace('_', '-', $lang);
+		$this->assign('language', $lang);
+		$this->assign('locale', $locale);
 
 		if(\OC::$server->getSystemConfig()->getValue('installed', false)) {
 			if (empty(self::$versionHash)) {
@@ -151,7 +169,8 @@ class TemplateLayout extends \OC_Template {
 					$this->config,
 					\OC::$server->getGroupManager(),
 					\OC::$server->getIniWrapper(),
-					\OC::$server->getURLGenerator()
+					\OC::$server->getURLGenerator(),
+					\OC::$server->getCapabilitiesManager()
 				);
 				$this->assign('inline_ocjs', $jsConfigHelper->getConfig());
 			} else {
@@ -175,7 +194,9 @@ class TemplateLayout extends \OC_Template {
 		if(\OC::$server->getSystemConfig()->getValue('installed', false)
 			&& !\OCP\Util::needUpgrade()
 			&& $pathInfo !== ''
-			&& !preg_match('/^\/login/', $pathInfo)) {
+			&& !preg_match('/^\/login/', $pathInfo)
+			&& $renderAs !== 'error'
+		) {
 			$cssFiles = self::findStylesheetFiles(\OC_Util::$styles);
 		} else {
 			// If we ignore the scss compiler,
@@ -194,9 +215,20 @@ class TemplateLayout extends \OC_Template {
 			if (substr($file, -strlen('print.css')) === 'print.css') {
 				$this->append( 'printcssfiles', $web.'/'.$file . $this->getVersionHashSuffix() );
 			} else {
-				$this->append( 'cssfiles', $web.'/'.$file . $this->getVersionHashSuffix($web, $file)  );
+				$suffix = $this->getVersionHashSuffix($web, $file);
+
+				if (strpos($file, '?v=') == false) {
+					$this->append( 'cssfiles', $web.'/'.$file . $suffix);
+				} else {
+					$this->append( 'cssfiles', $web.'/'.$file . '-' . substr($suffix, 3));
+				}
+
 			}
 		}
+
+		/** @var InitialStateService $initialState */
+		$initialState = \OC::$server->query(InitialStateService::class);
+		$this->assign('initialStates', $initialState->getInitialStates());
 	}
 
 	/**
@@ -294,12 +326,7 @@ class TemplateLayout extends \OC_Template {
 			$theme,
 			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
 			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
-			new JSCombiner(
-				\OC::$server->getAppDataDir('js'),
-				\OC::$server->getURLGenerator(),
-				\OC::$server->getMemCacheFactory()->create('JS'),
-				\OC::$server->getSystemConfig()
-			)
+			\OC::$server->query(JSCombiner::class)
 			);
 		$locator->find($scripts);
 		return $locator->getResources();
